Subject: Built motion from commit 22bc4a4.|0.0.16
From: Motion Team <[email-masked]>
Date: Mon, 11 Jan 2016 12:29:04 +0000 (+0100)

Built motion from commit 22bc4a4.|0.0.16
---

diff --git a/package.json b/package.json
index 956cdf1..e2e677f 100644
--- a/package.json
+++ b/package.json
@@ -1,6 +1,6 @@
 {
   "name": "motion",
-  "version": "0.0.16",
+  "version": "0.0.17",
   "main": "server/app.js",
   "dependencies": {
     "accept-language-parser": "^1.0.2",
diff --git a/public/assets/images/media/zendesk2.png b/public/assets/images/media/zendesk2.png
index 7f9f6b6..70d7c5f 100644
Binary files a/public/assets/images/media/zendesk2.png and b/public/assets/images/media/zendesk2.png differ
diff --git a/release-notes/changelog_0.0.15.txt b/release-notes/changelog_0.0.16.txt
similarity index 92%
rename from release-notes/changelog_0.0.15.txt
rename to release-notes/changelog_0.0.16.txt
index 19505ff..2be4f73 100644
--- a/release-notes/changelog_0.0.15.txt
+++ b/release-notes/changelog_0.0.16.txt
@@ -1,5 +1,7 @@
 # xCALLY MOTION Changelog
 
+- * 96837d8 - 2016-01-11: Asterisk Configuration File 
+- * 9626622 - 2016-01-11: fixed back compatibility languages 
 - * 4143fce - 2016-01-11: Updated reports APIs. 
 - * 7d148f3 - 2016-01-11: bower.json 
 - * d7331e9 - 2016-01-11: server side .yo-rc.json 
diff --git a/server/api/freshdesk_configuration/freshdesk_configuration.controller.js b/server/api/freshdesk_configuration/freshdesk_configuration.controller.js
index f3f01da..4c3d44d 100644
--- a/server/api/freshdesk_configuration/freshdesk_configuration.controller.js
+++ b/server/api/freshdesk_configuration/freshdesk_configuration.controller.js
@@ -44,7 +44,7 @@ function handleEntityNotFound(res) {
 function saveUpdates(updates) {
   return function(entity) {
     return entity.updateAttributes(updates)
-      .then(updated => {
+      .then(function(updated) {
         return updated;
       });
   };
@@ -54,7 +54,7 @@ function removeEntity(res) {
   return function(entity) {
     if (entity) {
       return entity.destroy()
-        .then(() => {
+        .then(function() {
           res.status(204).end();
         });
     }
diff --git a/server/app.js b/server/app.js
index 208ae47..384cf15 100644
--- a/server/app.js
+++ b/server/app.js
@@ -42,7 +42,8 @@ var io = require('socket.io')(server, {
   path: '/socket.io-client'
 });
 
-var ami = require('asterisk-manager')('5038', '185.43.210.57', 'xcall', 'xcall1234', true);
+var ami = require('asterisk-manager')(config.asterisk.port, config.asterisk.host,
+  config.asterisk.username, config.asterisk.password, true);
 ami.keepConnected();
 
 //Initialization Kue
diff --git a/server/config/environment/astconf.json b/server/config/environment/astconf.json
new file mode 100644
index 0000000..6036e81
--- /dev/null
+++ b/server/config/environment/astconf.json
@@ -0,0 +1,20 @@
+{
+  "development": {
+    "host": "develop.xcallymotion.com",
+    "port": "5038",
+    "username": "xcall",
+    "password": "xcall1234"
+  },
+  "test": {
+    "host": "localhost",
+    "port": "5038",
+    "username": "xcall",
+    "password": "xcall1234"
+  },
+  "production": {
+    "host": "localhost",
+    "port": "5038",
+    "username": "xcall",
+    "password": "xcall1234"
+  }
+}
diff --git a/server/config/environment/config.json b/server/config/environment/dbconf.json
similarity index 79%
rename from server/config/environment/config.json
rename to server/config/environment/dbconf.json
index 1ddcbe4..2685297 100644
--- a/server/config/environment/config.json
+++ b/server/config/environment/dbconf.json
@@ -1,10 +1,10 @@
 {
   "development": {
-    "host": "127.0.0.1",
+    "host": "localhost",
     "port": 3306,
-    "database": "xcally",
-    "username": "root",
-    "password": "peppe88",
+    "database": "motion",
+    "username": "xcall",
+    "password": "xC@LL1234",
     "dialect": "mysql"
   },
   "test": {
diff --git a/server/config/environment/config_history.json b/server/config/environment/dbconfhistory.json
similarity index 79%
rename from server/config/environment/config_history.json
rename to server/config/environment/dbconfhistory.json
index 1ddcbe4..2685297 100644
--- a/server/config/environment/config_history.json
+++ b/server/config/environment/dbconfhistory.json
@@ -1,10 +1,10 @@
 {
   "development": {
-    "host": "127.0.0.1",
+    "host": "localhost",
     "port": 3306,
-    "database": "xcally",
-    "username": "root",
-    "password": "peppe88",
+    "database": "motion",
+    "username": "xcall",
+    "password": "xC@LL1234",
     "dialect": "mysql"
   },
   "test": {
diff --git a/server/config/environment/index.js b/server/config/environment/index.js
index b014b24..476cd75 100644
--- a/server/config/environment/index.js
+++ b/server/config/environment/index.js
@@ -32,9 +32,9 @@ var all = {
 
   // Secret for session, you will want to change this and make it an environment variable
   session: {
-    name: 'xcally-shuttle-name',
-    secret: 'xcally-shuttle-secret',
-    token: 'xcally-shuttle-token',
+    name: 'xcally-motion-name',
+    secret: 'xcally-motion-secret',
+    token: 'xcally-motion-token',
     cookie: {
       path: '/',
       httpOnly: true,
diff --git a/server/config/environment/production.js b/server/config/environment/production.js
index 8d07d20..6d0faa4 100644
--- a/server/config/environment/production.js
+++ b/server/config/environment/production.js
@@ -1,12 +1,13 @@
 'use strict';
 
-var db = require('./config.json').production;
-var db_history = require('./config_history.json').production;
-
+var dbconf = require('./dbconf.json').production;
+var dbconfhistory = require('./dbconfhistory.json').production;
+var astconf = require('./astconf.json').production;
 // Production specific configuration
-// =================================
+// ==================================
 module.exports = {
-  db: db,
-  db_history: db_history,
-  seedDB: false
+  db: dbconf, // MySQL connection options
+  db_history: dbconfhistory, // MySQL connection options
+  asterisk: astconf, // Asterisk connection options
+  seedDB: true
 };
diff --git a/server/config/environment/test.js b/server/config/environment/test.js
index baf693e..8d6bd9f 100644
--- a/server/config/environment/test.js
+++ b/server/config/environment/test.js
@@ -1,11 +1,13 @@
 'use strict';
 
-var db = require('./config.json').test;
-var db_history = require('./config_history.json').test;
-
+var dbconf = require('./dbconf.json').test;
+var dbconfhistory = require('./dbconfhistory.json').test;
+var astconf = require('./astconf.json').test;
 // Test specific configuration
-// ===========================
+// ==================================
 module.exports = {
-  db: db,
-  db_history: db_history
+  db: dbconf, // MySQL connection options
+  db_history: dbconfhistory, // MySQL connection options
+  asterisk: astconf, // Asterisk connection options
+  seedDB: true
 };
diff --git a/server/config/environment/development.js b/server/config/environment/development.js
index ad87cb7..90dc82e 100644
--- a/server/config/environment/development.js
+++ b/server/config/environment/development.js
@@ -1,13 +1,13 @@
 'use strict';
 
-var db = require('./config.json').development;
-var db_history = require('./config_history.json').development;
-
+var dbconf = require('./dbconf.json').development;
+var dbconfhistory = require('./dbconfhistory.json').development;
+var astconf = require('./astconf.json').development;
 // Development specific configuration
 // ==================================
 module.exports = {
-  // MySQL connection options
-  db: db,
-  db_history: db_history,
+  db: dbconf, // MySQL connection options
+  db_history: dbconfhistory, // MySQL connection options
+  asterisk: astconf, // Asterisk connection options
   seedDB: true
 };